#
# spec file for package k3b
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_with ffmpeg
%bcond_with mad
%bcond_with lame

Name:           k3b
BuildRequires:  cups-devel libkcddb4-devel ruby-devel sqlite-devel libtag-devel
BuildRequires:  libkcompactdisc4-devel libkdepimlibs4-devel tse3-devel update-desktop-files
BuildRequires:  gstreamer010-devel libmtp-devel libvisual-devel libxine1-devel
BuildRequires:  flac-devel libQtWebKit-devel libdvdread-devel libvorbis-devel
BuildRequires:  dbus-1-glib-devel libogg-devel libsamplerate-devel libsndfile-devel
BuildRequires:  libmpcdec-devel libmusicbrainz-devel
# only needed to patch broken images in the upstream tarball:
BuildRequires:  ImageMagick
%if 0%{?suse_version} < 1140
BuildRequires:  libnjb-devel
%endif
%if %{with ffmpeg}
BuildRequires:  libffmpeg-devel
%endif
%if %{with mad}
BuildRequires:  libmad-devel
%endif
%if %{with lame}
BuildRequires:  libmp3lame-devel
%endif
Url:            http://k3b.sourceforge.net/
License:        GPLv2+
Group:          Productivity/Multimedia/CD/Record
Summary:        A Universal CD and DVD Burning Application
Requires:       /usr/bin/cdrecord /usr/bin/mkisofs /usr/bin/cdrdao dvd+rw-tools
Version:        2.0.2
Release:        19.3
%define rversion %version
# svn.kde.org/home/kde/trunk/extragear/multimedia/k3b
Source0:        k3b-%{version}.tar.bz2
Patch0:		k3b-kdeversion.patch
Patch1:         initial-preference.diff
Patch3:         add_mimetypes_bnc661777.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%kde4_runtime_requires
Requires(post):     shared-mime-info
Requires(postun):   shared-mime-info
Provides:       kde4-k3b = 4.2.1.svn942189
Provides:       kde4-k3b = 4.2.2.svn951754
Obsoletes:      kde4-k3b <= 4.2.2.svn951754
Recommends:     %{name}-lang = %{version}
%if 0%{?suse_version} >= 1030
BuildRequires:  fdupes
%endif

%description
K3b is a CD burning application that supports Ogg Vorbis, MP3 audio
files, DVD burning, CDDB, and much more.



Authors:
--------
    Sebastian Trueg <trueg@informatik.uni-freiburg.de>
    Thomas Froescher <tfroescher@gmx.de>

%package devel
Summary:        A Universal CD and DVD Burning Application
Group:          Development/Libraries/C and C++
Requires:       %name = %version

%description devel
K3b is a CD burning application that supports Ogg Vorbis, MP3 audio
files, DVD burning, CDDB, and much more.



Authors:
--------
    Sebastian Trueg <trueg@informatik.uni-freiburg.de>
    Thomas Froescher <tfroescher@gmx.de>

%if %{with ffmpeg} || %{with mad} || %{with lame}
%package codecs
Summary:        Full Multimedia Codec Support for k3b
Group:          Productivity/Multimedia/CD/Record
Requires:       %name = %version
%kde4_runtime_requires

%description codecs
K3b is a CD burning application that supports Ogg Vorbis, MP3 audio
files, DVD burning, CDDB, and much more.

This package contains the support for MP3 and similar codecs.



Authors:
--------
    Sebastian Trueg <trueg@informatik.uni-freiburg.de>
    Thomas Froescher <tfroescher@gmx.de>
%endif

%lang_package
%prep
%setup -q -n k3b-%{version}
%patch0
%patch1
%patch3

%if %{with mad}
echo "WITH MAD"
%else
echo "WITHOUT MAD"
%endif
%if %{with lame}
echo "WITH LAME"
%else
echo "WITHOUT LAME"
%endif
%if %{with ffmpeg}
echo "WITH FFMPEG"
%else
echo "WITHOUT FFMPEG"
%endif

# patch image with wrong dimensions
pushd src/icons/actions
for f in hi16*.png; do
    geom=$(identify -ping "$f"|cut -f3 -d" ")
    x=${geom%x*}
    y=${geom#*x}
    if [ "$x" != "16" -o "$y" != "16" ]; then
        if [ "$x" -gt "$y" ]; then
            nugeom="${x}x${x}"
            grav=south
        elif [ "$x" -lt "$y" ]; then
            nugeom="${y}x${y}"
            grav=center
        else
            nugeom=""
        fi
        [ -n "$nugeom" ] && mogrify -extent "$nugeom" -background transparent -gravity "$grav" "$f"
        mogrify -scale 16x16 -background transparent "$f"
    fi
done
popd #src/icons/actions

%build
%if 0%{?suse_version} > 1130
CMAKEPARAMS="-DK3B_ENABLE_HAL_SUPPORT=OFF"
%else
CMAKEPARAMS=""
%endif

  %cmake_kde4 -d build -- $CMAKEPARAMS
  %make_jobs

%install
  pushd build
  %makeinstall

  %if %{with mad}
  %__install -D -m0755 lib/k3bmaddecoder.so %buildroot/%_libdir/kde4/k3bmaddecoder.so
  %endif

  popd
  %suse_update_desktop_file k3b DiscBurning
  %kde_post_install
  rm -rf $RPM_BUILD_ROOT/usr/share/locale/sr@ijekavian
  rm -rf $RPM_BUILD_ROOT/usr/share/locale/sr@ijekavianlatin
  %find_lang k3b k3b.lang
  %find_lang k3bsetup k3b.lang
  %find_lang libk3b k3b.lang
  %find_lang libk3bdevice k3b.lang
  %find_lang kio_videodvd k3b.lang
  mkdir -p $RPM_BUILD_ROOT/usr/share/icons/hicolor/scalable/apps

%if 0%{?suse_version} >= 1030
%fdupes -s "%{buildroot}%{_datadir}/locale/"
%fdupes -s "%{buildroot}%{_datadir}/kde4/apps/k3b/icons/"
%fdupes -s "%{buildroot}%{_datadir}/kde4/apps/k3b/pics/"
%endif

%post
/sbin/ldconfig
/usr/bin/update-mime-database %{_datadir}/mime &> /dev/null || :

%postun
/sbin/ldconfig
/usr/bin/update-mime-database %{_datadir}/mime &> /dev/null || :

%clean
%{?buildroot:%__rm -rf "%{buildroot}"}

%files lang -f k3b.lang

%files
%defattr(-,root,root)
/usr/bin/k3b
/usr/bin/k3bsetup
%dir %_libdir/kde4
%_libdir/kde4/k3baudiometainforenamerplugin.so
%_libdir/kde4/k3baudioprojectcddbplugin.so
%_libdir/kde4/k3bexternalencoder.so
%_libdir/kde4/k3bflacdecoder.so
%_libdir/kde4/k3blibsndfiledecoder.so
%_libdir/kde4/k3bmpcdecoder.so
%_libdir/kde4/k3boggvorbisdecoder.so
%_libdir/kde4/k3boggvorbisencoder.so
%_libdir/kde4/k3bsoxencoder.so
%_libdir/kde4/k3bwavedecoder.so
%_libdir/kde4/kcm_k3bexternalencoder.so
%_libdir/kde4/kcm_k3boggvorbisencoder.so
%_libdir/kde4/kcm_k3bsetup.so
%_libdir/kde4/kcm_k3bsoxencoder.so
/usr/%_lib/kde4/kio_videodvd.so
/usr/%_lib/libk3blib.so.*
/usr/%_lib/libk3bdevice.so.*
/usr/%_lib/kde4/libexec/k3bsetuphelper
/usr/share/applications/kde4/k3b.desktop
/usr/share/kde4/apps/k3b
/usr/share/kde4/apps/konqsidebartng/virtual_folders/services/videodvd.desktop
%dir /usr/share/kde4/services
/usr/share/kde4/services/ServiceMenus/k3b_*
/usr/share/kde4/services/k3baudiometainforenamerplugin.desktop
/usr/share/kde4/services/k3baudioprojectcddbplugin.desktop
/usr/share/kde4/services/k3bexternalencoder.desktop
/usr/share/kde4/services/k3bflacdecoder.desktop
/usr/share/kde4/services/k3blibsndfiledecoder.desktop
/usr/share/kde4/services/k3bmpcdecoder.desktop
/usr/share/kde4/services/k3boggvorbisdecoder.desktop
/usr/share/kde4/services/k3boggvorbisencoder.desktop
/usr/share/kde4/services/k3bsetup.desktop
/usr/share/kde4/services/k3bsoxencoder.desktop
/usr/share/kde4/services/k3bwavedecoder.desktop
/usr/share/kde4/services/kcm_k3bexternalencoder.desktop
/usr/share/kde4/services/kcm_k3boggvorbisencoder.desktop
/usr/share/kde4/services/kcm_k3bsoxencoder.desktop
/usr/share/kde4/services/videodvd.protocol
/usr/share/kde4/servicetypes/k3bplugin.desktop
%if %suse_version < 1120
/usr/share/PolicyKit/policy/org.kde.kcontrol.k3bsetup.policy
%else
/usr/share/polkit-1/actions/org.kde.kcontrol.k3bsetup.policy
%endif
%dir /usr/share/kde4/apps/solid
%dir /usr/share/kde4/apps/solid/actions
/usr/share/kde4/apps/solid/actions/k3b_*.desktop
/usr/share/mime/packages/x-k3b.xml
/usr/share/icons/hicolor/*/apps/k3b.*
%if %suse_version < 1120
%dir /usr/share/locale/hne
%dir /usr/share/locale/hne/LC_MESSAGES
%endif
/etc/dbus-1/system.d/org.kde.kcontrol.k3bsetup.conf
/usr/share/dbus-1/system-services/org.kde.kcontrol.k3bsetup.service

%files devel
%defattr(-,root,root)
/usr/include/k3b*
/usr/%_lib/libk3blib.so
/usr/%_lib/libk3bdevice.so

%if %{with ffmpeg} || %{with mad} || %{with lame}
%files codecs
%defattr(-,root,root)
%if %{with ffmpeg}
%_libdir/kde4/k3bffmpegdecoder.so
%_datadir/kde4/services/k3bffmpegdecoder.desktop
%endif #ffmpeg
%if %{with mad}
%_libdir/kde4/k3bmaddecoder.so
%_datadir/kde4/services/k3bmaddecoder.desktop
%endif #mad
%if %{with lame}
%_libdir/kde4/k3blameencoder.so
%_libdir/kde4/kcm_k3blameencoder.so
%_datadir/kde4/services/k3blameencoder.desktop
%_datadir/kde4/services/kcm_k3blameencoder.desktop
%endif #lame
%endif #codecs

%changelog
